==> react-native-web-jsonschema-form-1.0.32.tgz: package/fields/BooleanField.js <==
import _get from "lodash/get";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React from 'react';
import { StyleSheet } from 'react-native';
import AbstractField from './AbstractField';
const styles = StyleSheet.create({
  padding: {
    paddingLeft: 10
  }
});

class BooleanField extends AbstractField {
  getDefaultWidget() {
    const {
      widgets
    } = this.props;
    return widgets.HiddenWidget;
  }

  getWidget() {
    const {
      widgets,
      uiSchema
    } = this.props;
    const widgetName = uiSchema['ui:widget'];

    const trueText = _get(uiSchema, ['ui:options', 'trueText'], 'Yes');

    const trueValue = _get(uiSchema, ['ui:options', 'trueValue'], true);

    const falseText = _get(uiSchema, ['ui:options', 'falseText'], 'No');

    const falseValue = _get(uiSchema, ['ui:options', 'falseValue'], false);

    let Widget;

    if (!widgetName || widgetName === 'checkbox') {
      const {
        CheckboxWidget
      } = widgets;

      Widget = ({
        value,
        ...props
      }) => React.createElement(CheckboxWidget, _extends({}, props, {
        value: trueValue,
        checked: value === trueValue
      }));
    } else if (widgetName === 'radio') {
      const {
        RadioWidget
      } = widgets;

      Widget = ({
        value,
        style,
        ...props
      }) => React.createElement(React.Fragment, null, React.createElement(RadioWidget, _extends({}, props, {
        text: trueText,
        checked: value === trueValue,
        style: [uiSchema['ui:inline'] && uiSchema['ui:title'] !== false ? styles.padding : null, style],
        value: trueValue
      })), React.createElement(RadioWidget, _extends({}, props, {
        text: falseText,
        checked: value === falseValue,
        style: [uiSchema['ui:inline'] ? styles.padding : null, style],
        value: falseValue
      })));
    }

    return Widget;
  }

}

export default BooleanField;

==> react-native-web-jsonschema-form-1.1.8.tgz: package/fields/BooleanField.js <==
import _get from "lodash/get";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React from 'react';
import { StyleSheet } from 'react-native';
import AbstractField from './AbstractField';
const styles = StyleSheet.create({
  padding: {
    paddingLeft: 10
  },
  inline: {
    marginBottom: 10
  }
});

class BooleanField extends AbstractField {
  getDefaultWidget() {
    const {
      widgets
    } = this.props;
    return widgets.HiddenWidget;
  }

  getWidget() {
    const {
      widgets,
      uiSchema
    } = this.props;
    const widgetName = uiSchema['ui:widget'];

    const trueText = _get(uiSchema, ['ui:options', 'trueText'], 'Yes');

    const trueValue = _get(uiSchema, ['ui:options', 'trueValue'], true);

    const falseText = _get(uiSchema, ['ui:options', 'falseText'], 'No');

    const falseValue = _get(uiSchema, ['ui:options', 'falseValue'], false);

    let Widget;

    if (!widgetName || widgetName === 'checkbox') {
      const {
        CheckboxWidget
      } = widgets;

      Widget = ({
        value,
        ...props
      }) => React.createElement(CheckboxWidget, _extends({}, props, {
        value: trueValue,
        checked: value === trueValue
      }));
    } else if (widgetName === 'radio' || widgetName === 'radiobox') {
      const {
        RadioWidget
      } = widgets;
      const inlineOptions = uiSchema['ui:options'] && uiSchema['ui:options'].inline;

      Widget = ({
        value,
        style,
        ...props
      }) => React.createElement(React.Fragment, null, React.createElement(RadioWidget, _extends({}, props, {
        auto: uiSchema['ui:inline'] || inlineOptions,
        text: trueText,
        checked: value === trueValue,
        style: [uiSchema['ui:inline'] && uiSchema['ui:title'] !== false ? styles.padding : null, uiSchema['ui:inline'] || inlineOptions ? styles.inline : null, style],
        value: trueValue
      })), React.createElement(RadioWidget, _extends({}, props, {
        auto: uiSchema['ui:inline'] || inlineOptions,
        text: falseText,
        checked: value === falseValue,
        style: [uiSchema['ui:inline'] || inlineOptions ? [styles.padding, styles.inline] : null, style],
        value: falseValue
      })));
    }

    return Widget;
  }

}

export default BooleanField;
